<?php

namespace App\Http\Controllers;

use App\Models\Item;
use App\Models\Menu;
use ImageIntervention;
use App\Models\City;
use App\Models\Image;
use Illuminate\Http\Request;
use Illuminate\Support\Str;

class ItemController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        return view('pages.items.index');
    }


    public function getItemsForAjax(Request $request)
    {
       
        if ($request->ajax()) {
            return Datatables()->of(Item::all())
                ->addIndexColumn()

                ->addColumn('action', function ($data) {

                    $btn = ' <a class="btn btn-dark shadow btn-xs sharp mr-1" href="' . url(currentLocale().'/admin/items/edit/' . $data->id) . '" ><i class="fa fa-eye"></i></a>';

                    
                  $btn = $btn . ' <a class="btn btn-danger shadow btn-xs sharp mr-1" href="javascript:void(0)" onclick="deleteItem(' . $data->id . ')"><i class="fa fa-trash"></i></a>';
                    

                    return $btn;
                })
                ->rawColumns(['status_badge','action'])
                ->make(true);
        } else {
            abort(403);
        }
    }



    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $cityess = City::all();
        $menus = Menu::all();
        return view('pages.items.create',compact('menus','cityess'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $data=($request->except('poster','images'));
     
     	$city = City::findOrFail($request->city_id);
        $item = Item::create(array_merge($data,['type' => $city->title_en,'slug' => Str::slug(translit($request->title_en),'-')]));
        
        if ($request->file('poster')){
            $filePath = '/image-'.time().'.jpg';
            $image = $request->poster;
            $image->move('images/',$filePath);
            $item->images()->create(['url' => $filePath]);
        }
        // if ($request->images){
        //     $imgPaths = [];
        //     foreach ($request->images as $file) {
        //         $filePath = '/image-' . Str::random(10).'-'.time() . '.jpg';
        //         $file->move('images/', $filePath);
        //         $imgPaths[] = ['url' => $filePath];
        //     }
        //     $item->images()->createMany($imgPaths);
        // }

        foreach($request->images as $file){
            $filePath = '/image-' . Str::random(10).'-'.time() . '.jpg';
             // $name = '/image-'.time().'.'.$file->extension();
             // echo $filePath;
             $img = ImageIntervention::make('' . $file . '')->orientate();
                    $img->resize(1200, null, function ($constraint) {
                        $constraint->aspectRatio();
                        $constraint->upsize();
                    });
 
                //  $img->insert('https://batumils.ge/batumils2_last_waterk.png', 'center', 10, 10);
               
                 $img->save('images/' . $filePath);
 
             $item->images()->create(['url' => $filePath]);
         }

        return redirect()->back()->with('success','გვერდი წარმატებით დაემატა!');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($locale='ka',$id)
    {
       
        $item=Item::with('images')->findOrFail($id);
        $cityess = City::all();
        return view('pages.items.edit', compact('item','cityess'));

    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function updateItem(Request $request, $id)
    {
         $item = Item::with('images')->findOrFail($request->item_id);
 
        if ($request->file('poster')){
            $filePath = '/image-'.time().'.jpg';
            $image = $request->poster;
            $image->move('images/',$filePath);
            $item->images()->create(['url' => $filePath]);
        }
        if ($request->images){
            $imgPaths = [];
            foreach ($request->images as $file) {
                $filePath = '/image-' . Str::random(10).'-'.time() . '.jpg';
                $file->move('images/', $filePath);
                $imgPaths[] = ['url' => $filePath];
            }
            $item->images()->createMany($imgPaths);
        }
        $item->update($request->except('poster','images','item_id'));

        return redirect()->back()->with('success','გვერდი წარმატებით დაემატა!');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function delete(Request $request)
    {
        // Room::findOrFail($request->id)->delete();
        try {
            Item::findOrFail($request->id)->delete();
            return jsonResponse(['status' => 1]);
        } catch (\Exception $exception){
            return jsonResponse(['status' => 0]);
        }
    }

      public function deleteImage(Request $request){
        try{
            $item = Image::findOrFail($request->id)->delete();
            //$car->iamges()->delete();
            return jsonResponse(['status' => 1]);
        } catch(\Exception $ex){
            return jsonResponse(['status' => 0]);
        }
    }

}
