<?php

namespace App\Http\Controllers;

use App\Models\Room;
use App\Models\Menu;
use App\Models\Image;
use Illuminate\Http\Request;
use Illuminate\Support\Str;

class RoomController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        return view('pages.rooms.index');
    }


    public function getRoomsForAjax(Request $request)
    {
       
        if ($request->ajax()) {
            return Datatables()->of(Room::all())
                ->addIndexColumn()

                ->addColumn('action', function ($data) {

                    $btn = ' <a class="btn btn-dark shadow btn-xs sharp mr-1" href="' . url(currentLocale().'/admin/rooms/edit/' . $data->id) . '" ><i class="fa fa-eye"></i></a>';

                    
                  $btn = $btn . ' <a class="btn btn-danger shadow btn-xs sharp mr-1" href="javascript:void(0)" onclick="deleteRoom(' . $data->id . ')"><i class="fa fa-trash"></i></a>';
                    

                    return $btn;
                })
                ->rawColumns(['status_badge','action'])
                ->make(true);
        } else {
            abort(403);
        }
    }



    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $menus = Menu::all();
        return view('pages.rooms.create',compact('menus'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $data=($request->except('poster','images'));
        $room = Room::create(array_merge($data,['slug' => Str::slug(translit($request->title),'-')]));
        
        if ($request->file('poster')){
            $filePath = '/image-'.time().'.jpg';
            $image = $request->poster;
            $image->move('images/',$filePath);
            $room->images()->create(['url' => $filePath]);
        }
        if ($request->images){
            $imgPaths = [];
            foreach ($request->images as $file) {
                $filePath = '/image-' . Str::random(10).'-'.time() . '.jpg';
                $file->move('images/', $filePath);
                $imgPaths[] = ['url' => $filePath];
            }
            $room->images()->createMany($imgPaths);
        }

        return redirect()->back()->with('success','გვერდი წარმატებით დაემატა!');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($locale='ka',$id)
    {
       
        $room=Room::with('images')->findOrFail($id);
         $menus = Menu::all();
        return view('pages.rooms.edit', compact('room','menus'));

    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function updateRoom(Request $request, $id)
    {
         $room = Room::with('images')->findOrFail($request->room_id)->update($request->except('poster','images','room_id'));

        if ($request->file('poster')){
            $filePath = '/image-'.time().'.jpg';
            $image = $request->poster;
            $image->move('images/',$filePath);
            $room->images()->create(['url' => $filePath]);
        }
        if ($request->images){
            $imgPaths = [];
            foreach ($request->images as $file) {
                $filePath = '/image-' . Str::random(10).'-'.time() . '.jpg';
                $file->move('images/', $filePath);
                $imgPaths[] = ['url' => $filePath];
            }
            $room->images()->createMany($imgPaths);
        }

        return redirect()->back()->with('success','გვერდი წარმატებით დაემატა!');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function delete(Request $request)
    {
        // Room::findOrFail($request->id)->delete();
        try {
            Room::findOrFail($request->id)->delete();
            return jsonResponse(['status' => 1]);
        } catch (\Exception $exception){
            return jsonResponse(['status' => 0]);
        }
    }

      public function deleteImage(Request $request){
        try{
            $room = Image::findOrFail($request->id)->delete();
            //$car->iamges()->delete();
            return jsonResponse(['status' => 1]);
        } catch(\Exception $ex){
            return jsonResponse(['status' => 0]);
        }
    }

}
