<?php

namespace App\Http\Controllers;

use App\Models\Shop;
use App\Models\Menu;
use ImageIntervention;
use App\Models\City;
use App\Models\Image;
use Illuminate\Http\Request;
use Illuminate\Support\Str;

class ShopController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        return view('pages.shops.index');
    }


    public function getShopsForAjax(Request $request)
    {
       
        if ($request->ajax()) {
            return Datatables()->of(Shop::all())
                ->addIndexColumn()

                ->addColumn('action', function ($data) {

                    $btn = ' <a class="btn btn-dark shadow btn-xs sharp mr-1" href="' . url(currentLocale().'/admin/shops/edit/' . $data->id) . '" ><i class="fa fa-eye"></i></a>';

                    
                  $btn = $btn . ' <a class="btn btn-danger shadow btn-xs sharp mr-1" href="javascript:void(0)" onclick="deleteShop(' . $data->id . ')"><i class="fa fa-trash"></i></a>';
                    

                    return $btn;
                })
                ->rawColumns(['status_badge','action'])
                ->make(true);
        } else {
            abort(403);
        }
    }



    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $cityess = City::all();
        $menus = Menu::all();
        return view('pages.shops.create',compact('menus','cityess'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $data=($request->except('poster','images'));
      
        $shop = Shop::create(array_merge($data,['slug' => Str::slug(translit($request->title_en),'-')]));
        
        if ($request->file('poster')){
            $filePath = '/image-'.time().'.jpg';
            $image = $request->poster;
            $image->move('images/',$filePath);
            $shop->images()->create(['url' => $filePath]);
        }
        // if ($request->images){
        //     $imgPaths = [];
        //     foreach ($request->images as $file) {
        //         $filePath = '/image-' . Str::random(10).'-'.time() . '.jpg';
        //         $file->move('images/', $filePath);
        //         $imgPaths[] = ['url' => $filePath];
        //     }
        //     $item->images()->createMany($imgPaths);
        // }

        foreach($request->images as $image){
            // $filePath = '/image-' . Str::random(10).'-'.time() . '.jpg';
            $name = '/image-'.time().'.'.$image->extension();
            $img = ImageIntervention::make('' . $image . '')->orientate();
                   $img->resize(1200, null, function ($constraint) {
                       $constraint->aspectRatio();
                       $constraint->upsize();
                   });
              
                $img->save('images/' . $name);

                $shop->images()->create(['url' => $name]);
        }

        return redirect()->back()->with('success','გვერდი წარმატებით დაემატა!');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($locale='ka',$id)
    {
       
        $shop=Shop::with('images')->findOrFail($id);
        $cityess = City::all();
        return view('pages.shops.edit', compact('shop','cityess'));

    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function updateShop(Request $request, $id)
    {
         $shop = Shop::with('images')->findOrFail($request->shop_id);
 
        if ($request->file('poster')){
            $filePath = '/image-'.time().'.jpg';
            $image = $request->poster;
            $image->move('images/',$filePath);
            $shop->images()->create(['url' => $filePath]);
        }
        if ($request->images){
            $imgPaths = [];
            foreach ($request->images as $file) {
                $filePath = '/image-' . Str::random(10).'-'.time() . '.jpg';
                $file->move('images/', $filePath);
                $imgPaths[] = ['url' => $filePath];
            }
            $shop->images()->createMany($imgPaths);
        }
        $shop->update($request->except('poster','images','shop_id'));

        return redirect()->back()->with('success','გვერდი წარმატებით დაემატა!');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function delete(Request $request)
    {
        // Room::findOrFail($request->id)->delete();
        try {
            Shop::findOrFail($request->id)->delete();
            return jsonResponse(['status' => 1]);
        } catch (\Exception $exception){
            return jsonResponse(['status' => 0]);
        }
    }

      public function deleteImage(Request $request){
        try{
            $shop = Image::findOrFail($request->id)->delete();
            //$car->iamges()->delete();
            return jsonResponse(['status' => 1]);
        } catch(\Exception $ex){
            return jsonResponse(['status' => 0]);
        }
    }

}
