<?php

namespace App\Http\Controllers;

use Carbon\Carbon;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use App\Models\User;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Str;
use Spatie\Permission\Models\Role;

use Illuminate\Support\Arr;

class UserController extends Controller
{

    public function __construct()
    {
        $this->middleware('permission:user-list|user-create|user-edit|user-delete', ['only' => ['index','store']]);
        $this->middleware('permission:user-create', ['only' => ['create','store']]);
        $this->middleware('permission:user-edit', ['only' => ['edit','update']]);
        $this->middleware('permission:user-delete', ['only' => ['destroy']]);
    }

    public function index(Request $request)
    {
        $data = User::orderBy('id','DESC')->paginate(5);
        return view('users.index',compact('data'))
            ->with('i', ($request->input('page', 1) - 1) * 5);
    }

    public function changeNotification(Request $request)
    {
        try {
            User::where('id', currentUser()->id)->update(['domain' => $request->domain]);
            return jsonResponse(['status' => 1]);
        } catch (\Exception $exception){
            return jsonResponse(['status' => 0]);
        }
    }

    public function getUsersForAjax()
    {
        return Datatables()->of(User::latest()->get())
            ->addIndexColumn()
            ->addColumn('domain', function($data){
                return $data->domain.' <a target="_blank" href="https://'.$data->domain.'"><i class="fa fa-external-link-alt"></i></a>';

            })
            ->addColumn('role', function($data){
                $html = '';
                foreach ($data->getRoleNames() as $v){
                    $html .= "<span class='badge badge-success'>$v</span>";
                }
                return $html;
            })
            ->addColumn('action', function($data){
                $html = '';
                foreach ($data->getRoleNames() as $v){
//                return $data->getRolesNames();
                    if ($v === 'System Administrator' && currentUser()->id != 1){
                        $html .= '<i class="fa fa-exclamation-triangle" style="font-size: 21px;color: red;"></i>';
                    }else{
                        $html .=  $btn = ' <a class="btn btn-primary shadow btn-xs sharp mr-1" href="'.url(currentLocale()."/users/$data[id]/edit/").'"><i class="fa fa-edit"></i></a>';
                        if (currentUser()->can('user-delete')){
                            $html = $btn. ' <a class="btn btn-danger shadow btn-xs sharp mr-1" href="javascript:void(0)" onclick="deleteUser('.$data->id.')"><i class="fa fa-trash"></i></a>';
                        }
                    }
                }

                return $html;
            })
            ->rawColumns(['role','action'])
            ->make(true);

    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $roles = Role::where('name','!=','System Administrator')->pluck('name','name')->all();
        return view('users.create',compact('roles'));
    }

    public function store(Request $request)
    {
        $this->validate($request, [
            'name' => 'required',
            'email' => 'required|email|unique:users,email',
            'password' => 'required|same:confirm-password',
            'roles' => 'required'
        ]);

        $input = $request->all();
        $input['password'] = Hash::make($input['password']);

        $user = User::create($input);
        $user->assignRole($request->input('roles'));

        return redirect(url(currentLocale().'/users'))
            ->with('success','მომხმარებელი წარმატებით დარეგისტრირდა');
    }

    public function show($locale = 'ka',$id)
    {
        $user = User::find($id);
        return view('users.show',compact('user'));
    }

    public function edit($locale = 'ka',$id)
    {
        $user = User::find($id);
        $roles = Role::pluck('name','name')->all();
        $userRole = $user->roles->pluck('name','name')->all();

        return view('users.edit',compact('user','roles','userRole'));
    }

    public function getUserById($locale = 'ka', $id)
    {
        $user = User::findOrFail($id);
        return $user;
    }

    public function update($locale = 'ka',Request $request, $id)
    {
        $this->validate($request, [
            'name' => 'required',
            'email' => 'required|email|unique:users,email,'.$id,
            'password' => 'same:confirm-password',
            'roles' => 'required'
        ]);

        $input = $request->all();
        if(!empty($input['password'])){
            $input['password'] = Hash::make($input['password']);
        }else{
            $input = Arr::except($input,array('password'));
        }

        $user = User::find($id);
        $user->update($input);
        DB::table('model_has_roles')->where('model_id',$id)->delete();

        $user->assignRole($request->input('roles'));

        return redirect(url(currentLocale().'/users'))
            ->with('success','მომხმარებლის ინფორმაცია წარმატებით შეიცვალა');
    }

    public function destroy($id)
    {
        User::find($id)->delete();
        return redirect()->route('users.index')
            ->with('success','User deleted successfully');
    }

    public function deleteUser(Request $request)
    {
        try {
            User::findOrFail($request->id)->delete();
            return jsonResponse(['status' => 1]);
        }catch (\Exception $exception){
            return jsonResponse(['status' => 0]);
        }
    }
}
