<?php

define('TRANSL_FROM_LATIN', 1);
define('TRANSL_TO_LATIN', 2);

if (!function_exists('jsonResponse')) {
    function jsonResponse($data = [], int $status = 200)
    {
        return response()->json($data, $status);
    }
}

if (!function_exists('currentUser')) {
    function currentUser(){
        return optional(auth() -> user());
    }
}

if (!function_exists('currentLocale')) {
    function currentLocale(){
        return app()->currentLocale();
    }
}

if (!function_exists('localeUrl')) {
    function localeUrl($locale){
        $requestUri = request()->getRequestUri();
        $parsedRequestUri = explode('/',$requestUri);
        array_shift($parsedRequestUri);
        $parsedRequestUri[0] = $locale;
        return implode('/',$parsedRequestUri);
    }
}

if (!function_exists('generateCode')){
    function generateCode($length){
        $permitted_chars = '0123456789';
        return substr(str_shuffle($permitted_chars), 0, $length);
    }
}

if (!function_exists('usdRate')){
    function usdRate(){
        $url = "https://api.businessonline.ge/api/rates/nbg/USD";
        $currencyRate = json_decode(file_get_contents($url), true);
        return $currencyRate;
    }
}

if (!function_exists('getUserCount')) {
    function getUserCount(){
        $userCount = \App\Models\User::whereNotIn('id',[1])->get()->count();
        return $userCount;
    }
}

if (!function_exists('getCarsCount')) {
    function getCarsCount(){
        $carsCount = \App\Models\Car::all()->count();
        return $carsCount;
    }
}

if(!function_exists('translit')) {
    function translit($str, $mode = TRANSL_TO_LATIN)
    {
        $converter = array(
            'ა' => 'a',
            'ბ' => 'b',
            'გ' => 'g',
            'დ' => 'd',
            'ე' => 'e',
            'ვ' => 'v',
            'ზ' => 'z',
            'თ' => 't',
            'ი' => 'i',
            'კ' => 'k',
            'ლ' => 'l',
            'მ' => 'm',
            'ნ' => 'n',
            'ო' => 'o',
            'პ' => 'p',
            'ჟ' => 'zh',
            'რ' => 'r',
            'ს' => 's',
            'ტ' => 't',
            'უ' => 'u',
            'ფ' => 'p',
            'ქ' => 'q',
            'ღ' => 'g',
            'ყ' => 'k',
            'შ' => 'sh',
            'ჩ' => 'ch',
            'ც' => 'ts',
            'ძ' => 'dz',
            'წ' => 'ts',
            'ჭ' => 'ch',
            'ხ' => 'kh',
            'ჯ' => 'j',
            'ჰ' => 'h',
            //' ' => '-',
            'а' => 'a',
            'б' => 'b',
            'в' => 'v',
            'г' => 'g',
            'д' => 'd',
            'е' => 'e',
            'ё' => 'io',
            'ж' => 'zh',
            'з' => 'z',
            'и' => 'i',
            'й' => 'y',
            'к' => 'k',
            'л' => 'l',
            'м' => 'm',
            'н' => 'n',
            'о' => 'o',
            'п' => 'p',
            'р' => 'r',
            'с' => 's',
            'т' => 't',
            'у' => 'u',
            'ф' => 'f',
            'х' => 'h',
            'ц' => 'ts',
            'ч' => 'ch',
            'ш' => 'sh',
            'щ' => 'sht',
            'ъ' => 'a',
            'ы' => 'i',
            'ь' => 'y',
            'э' => 'e',
            'ю' => 'yu',
            'я' => 'ya'
        );
        if ($mode == TRANSL_FROM_LATIN) {
            $converter = array_flip($converter);
        }
        return strtr(strtolower($str), $converter);
    }
}

