<?php



use App\Http\Controllers\HomeController;
use App\Http\Controllers\UserController;
use App\Http\Controllers\PageController;
use App\Http\Controllers\BoxController;
use App\Http\Controllers\AboutController;
use App\Http\Controllers\RoomController;
use App\Http\Controllers\CityController;
use App\Http\Controllers\ItemController;
use App\Http\Controllers\ShopController;
use App\Models\User;
use App\Models\Page;
use App\Models\Menu;

use App\Models\Box;
use Carbon\Carbon;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Route;
use App\Http\Controllers\RoleController;
use Maatwebsite\Excel\Facades\Excel;
use Spatie\Activitylog\Models\Activity;


/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| contains the "web" middleware group. Now create something great!
|
*/
Route::get('/off', function () {
    $isOffline = IsOffline::find(1)->format();
    if ($isOffline['status'] == 0 || currentUser()->is_admin === 1) {
        return redirect('/home');
    }
    return view('offline.index', compact('isOffline'));
});

Route::get('/clear_cache',function (){
    \Illuminate\Support\Facades\Artisan::call('clear:cache');
});

Route::get('/', function (){
     //$Menus = Menu::with('categories')->get();
     //return $Menus;
    $currentLocale = app()->getLocale();
    if (key_exists('myLocale',$_COOKIE)){
        $currentLocale = $_COOKIE['myLocale'];
    }
    return redirect($currentLocale);
});







Route::group([
    'prefix' => '{locale}',
    'where' => ['locale' => '[a-zA-Z]{2}'],
    'middleware' => 'setlocale'
], function (){

    Route::get('/',[HomeController::class,'index']);
  	Route::get('/category/{id}',[HomeController::class,'showCategory']);
	Route::get('/item/{id}',[HomeController::class,'showItem']);
    Route::get('/page/{id}',function($locale = 'ka',$id){
        $pages = Page::where('menu_id',$id)->with('images')->get();
        return view('front.pages.page',compact('pages'));
        
    });

    Route::get('/about',[HomeController::class,'litzresort']);

    Route::get('/contact',[HomeController::class,'contact']);
    
    Route::post('/contactform',[HomeController::class,'contactform']);
    Route::post('/shopform',[HomeController::class,'shopform']);
    Route::get('/gallery',[HomeController::class,'gallery']);

    Route::get('/rooms',[HomeController::class,'rooms']);

    Route::get('/room/{id}/{slug}',[HomeController::class,'room']);

    Route::get('/cityes',[HomeController::class,'citys']);

    Route::get('/cityes/{id}/{slug}',[HomeController::class,'city']);
    Route::get('/reviews',[HomeController::class,'reviews']);
    Route::post('/review/store',[HomeController::class,'storeReview']);

    Route::get('/items',[HomeController::class,'items']);

    Route::get('/shops',[HomeController::class,'shops']);

    Route::get('/shop/{id}/{slug}',[HomeController::class,'shop']);

    Route::get('/excursions',[HomeController::class,'excursions']);

    Route::get('/item/{id}/{slug}',[HomeController::class,'item']);
 

    Route::get('/items/{id}/{slug}',[HomeController::class,'item']);



    Route::group(['prefix' => 'admin'], function (){
        Route::get('/', function () {
            if (Auth::check()) {
                return view('dashboard');
            }
            return view('auth.login');
        });
    Route::middleware(['auth', 'offline'])->group(function () {
        Route::get('/user', function (Request $request) {
            return $request->user();
        });

        Route::group(['prefix' => 'users'], function (){
            Route::get('/', [UserController::class,'index']);
            Route::get('/{id}/edit',[UserController::class,'edit']);
            Route::patch('/{id}/update',[UserController::class,'update']);
            Route::get('/{id}/show',[UserController::class,'show']);
            Route::get('/create',[UserController::class,'create']);
            Route::post('/store',[UserController::class,'store']);
            Route::get('/users_ajax', [UserController::class, 'getUsersForAjax']);
            Route::post('/delete_user', [UserController::class, 'deleteUser']);
        });

        Route::group(['prefix' => 'roles'], function (){
            Route::get('/', [RoleController::class,'index']);
            Route::get('/create', [RoleController::class,'create']);
            Route::post('/store',[RoleController::class,'store']);
            Route::get('/{id}/edit', [RoleController::class,'edit']);
            Route::patch('/{id}/update',[RoleController::class,'update']);
            Route::post('/delete_role',[RoleController::class,'deleteRole']);
        });

        Route::group(['prefix' => 'pages'], function (){
            Route::get('/',[PageController::class,'index']);
            Route::get('/pages_ajax',[PageController::class,'getPagesForAjax']);
            Route::get('/create',[PageController::class,'create']);
            Route::post('/store',[PageController::class,'store']);
            Route::post('/update',[PageController::class,'updatePage']);
            Route::post('/delete_image',[PageController::class,'deleteImage']);


            Route::get('/edit/{id}',[PageController::class,'edit']);

            Route::post('/delete_page',[PageController::class,'delete']);


        });
        Route::group(['prefix' => 'rooms'], function (){
            Route::get('/',[RoomController::class,'index']);
            Route::get('/rooms_ajax',[RoomController::class,'getRoomsForAjax']);
            Route::get('/create',[RoomController::class,'create']);
            Route::post('/store',[RoomController::class,'store']);
            Route::post('/update',[RoomController::class,'updateRoom']);
            Route::post('/delete_image',[RoomController::class,'deleteImage']);


            Route::get('/edit/{id}',[RoomController::class,'edit']);

            Route::post('/delete_room',[RoomController::class,'delete']);


        });


        Route::group(['prefix' => 'citys'], function (){
            Route::get('/',[CityController::class,'index']);
            Route::get('/citys_ajax',[CityController::class,'getCitysForAjax']);
            Route::get('/create',[CityController::class,'create']);
            Route::post('/store',[CityController::class,'store']);
            Route::post('/update',[CityController::class,'updateCity']);
            Route::post('/delete_image',[CityController::class,'deleteImage']);


            Route::get('/edit/{id}',[CityController::class,'edit']);

            Route::post('/delete_city',[CityController::class,'delete']);


        });


        Route::group(['prefix' => 'items'], function (){
            Route::get('/',[ItemController::class,'index']);
            Route::get('/items_ajax',[ItemController::class,'getItemsForAjax']);
            Route::get('/create',[ItemController::class,'create']);
            Route::post('/store',[ItemController::class,'store']);
            Route::post('/update',[ItemController::class,'updateItem']);
            Route::post('/delete_image',[ItemController::class,'deleteImage']);


            Route::get('/edit/{id}',[ItemController::class,'edit']);

            Route::post('/delete_item',[ItemController::class,'delete']);


        });


        Route::group(['prefix' => 'shops'], function (){
            Route::get('/',[ShopController::class,'index']);
            Route::get('/shops_ajax',[ShopController::class,'getshopsForAjax']);
            Route::get('/create',[ShopController::class,'create']);
            Route::post('/store',[ShopController::class,'store']);
            Route::post('/update',[ShopController::class,'updateShop']);
            Route::post('/delete_image',[ShopController::class,'deleteImage']);


            Route::get('/edit/{id}',[ShopController::class,'edit']);

            Route::post('/delete_shop',[ShopController::class,'delete']);


        });

        

         Route::group(['prefix' => 'boxes'], function (){
            Route::get('/',[BoxController::class,'index']);
            Route::get('/boxes_ajax',[BoxController::class,'getBoxsForAjax']);
            Route::get('/create',[BoxController::class,'create']);
            Route::post('/store',[BoxController::class,'store']);
            Route::post('/update',[BoxController::class,'updateBox']);
            Route::post('/delete_image',[BoxController::class,'deleteImage']);


            Route::get('/edit/{id}',[BoxController::class,'edit']);

            Route::post('/delete_box',[BoxController::class,'delete']);


        });


        Route::group(['prefix' => 'about'], function (){
            Route::get('/',[AboutController::class,'edit']);
            Route::post('/update',[AboutController::class,'updateAbout']);


        });


        










        Route::get('/my-profile', function () {
            return view('pages.my_profile');
        });


    });
    });
});

Auth::routes();



Route::get('/home', [HomeController::class, 'index'])->name('home');
